@@ -17,6 +17,7 @@
 #include <qt6keychain/keychain.h>
 
 using namespace QKeychain;
+using namespace Qt::StringLiterals;
 
 static const QString ewsWalletFolder = QStringLiteral("akonadi-ews");
 
@@ -51,7 +52,7 @@ void EwsSettings::requestMap()
     qCDebug(EWSRES_LOG) << "requestMap: start";
 
     auto readJob = new ReadPasswordJob(ewsWalletFolder, this);
-    readJob->setKey(config()->name());
+    readJob->setKey(config()->name() + "_map"_L1);
 
     connect(readJob, &ReadPasswordJob::finished, this, [this, readJob]() {
         QMap<QString, QString> map;
@@ -119,7 +120,7 @@ void EwsSettings::setMap(const QMap<QString, QString> &map)
     ds << map;
 
     auto writeJob = new WritePasswordJob(ewsWalletFolder, this);
-    writeJob->setKey(config()->name());
+    writeJob->setKey(config()->name() + "_map"_L1);
     writeJob->setBinaryData(mapData);
 
     connect(writeJob, &WritePasswordJob::finished, this, [writeJob]() {
